@@ -1,5 +1,5 @@
 #
-# $Id: Syslog.pm,v 0.1.1.3 2000/10/01 19:59:17 ram Exp $
+# $Id: Syslog.pm,v 0.2 2000/11/06 19:30:33 ram Exp $
 #
 #  Copyright (c) 1999, Raphael Manfredi
 #  
@@ -8,39 +8,29 @@
 #
 # HISTORY
 # $Log: Syslog.pm,v $
-# Revision 0.1.1.3  2000/10/01 19:59:17  ram
-# patch8: conforms to changed driver interface
-#
-# Revision 0.1.1.2  2000/06/20 21:25:44  ram
-# patch5: changed _init() signature to add stack trace penalty
-#
-# Revision 0.1.1.1  2000/03/05 22:23:32  ram
-# patch3: added end marker before pod
-#
-# Revision 0.1  1999/12/07 21:09:44  ram
-# Baseline for first alpha release.
+# Revision 0.2  2000/11/06 19:30:33  ram
+# Baseline for second Alpha release.
 #
 # $EndLog$
 #
 
 use strict;
-require Log::Agent::Driver;
 
 ########################################################################
 package Log::Agent::Driver::Syslog;
 
+require Log::Agent::Driver;
 use vars qw(@ISA);
-
 @ISA = qw(Log::Agent::Driver);
 
-use Sys::Syslog qw(:DEFAULT setlogsock);
+require Log::Agent::Channel::Syslog;
 
 #
 # ->make			-- defined
 #
 # Creation routine.
 #
-# Attributes (and switches that set them):
+# All switches are passed to Log::Agent::Channel::Syslog.
 #
 # prefix		the application name
 # facility		the syslog facility name to use ("auth", "daemon", etc...)
@@ -55,61 +45,20 @@ sub make {
 
 	my %set = (
 		-prefix		=> \$prefix,				# Handled by parent via _init
-		-facility	=> \$self->{'facility'},
-		-showpid	=> \$self->{'showpid'},
-		-socktype	=> \$self->{'socktype'},
-		-logopt		=> \$self->{'logopt'},
 	);
 
 	while (my ($arg, $val) = each %args) {
 		my $vset = $set{lc($arg)};
-		unless (ref $vset) {
-			require Carp;
-			Carp::croak("Unknown switch $arg");
-		}
+		next unless ref $vset;
 		$$vset = $val;
 	}
 
-	$self->{'logopt'} =~ s/\bpid\b//g;			# Must use showpid => 1
-	$self->{'logopt'} .= ' pid' if $self->showpid;
-
+	$self->{channel} = Log::Agent::Channel::Syslog->make(@_);
 	$self->_init($prefix, 0);					# 0 is the skip Carp penalty
 	return $self;
 }
 
-#
-# Attribute access
-#
-
-sub facility	{ $_[0]->{'facility'} || 'user' }
-sub showpid		{ $_[0]->{'showpid'} }
-sub socktype	{ $_[0]->{'socktype'} }
-sub logopt		{ $_[0]->{'logopt'} }
-sub connected	{ $_[0]->{'connected'} }
-
-#
-# ->connect
-#
-# Connect to syslogd.
-#
-sub connect {
-	my $self = shift;
-	setlogsock $self->socktype if $self->socktype;
-	openlog $self->prefix, $self->logopt, $self->facility;
-	$self->{'connected'}++;
-}
-
-#
-# ->disconnect
-#
-# Disconnect from syslogd.
-#
-sub disconnect {
-	my $self = shift;
-	return unless $self->connected;
-	closelog;
-	$self->{'connected'} = 0;
-}
+sub channel		{ $_[0]->{channel} }
 
 #
 # ->prefix_msg		-- defined
@@ -153,16 +102,14 @@ sub map_pri {
 }
 
 #
-# ->emit			-- defined
+# ->write			-- defined
 #
 # $channel is ignored
 #
-sub emit {
+sub write {
 	my $self = shift;
 	my ($channel, $priority, $logstring) = @_;
-	local $\ = undef;
-	$self->connect unless $self->connected;
-	syslog $priority, "%s", $logstring;
+	$self->channel->write($priority, $logstring);
 }
 
 1;	# for require
@@ -235,6 +182,6 @@ Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>
 
 =head1 SEE ALSO
 
-Log::Agent::Driver(3), Log::Agent(3).
+Log::Agent::Driver(3), Log::Agent::Channel::Syslog(3).
 
 =cut
